@@ -9,18 +9,19 @@
 #' is identical to the capture probability.
 #' Otherwise it is less.
 #'
-#' @inheritParams ypr_schedule
+#' @inheritParams params
 #' @param pi A vector of capture probabilities to calculate the exploitation probabilities for.
 #' @return A vector of exploitation probabilities.
-#' @seealso \code{\link{ypr_population}}
+#' @seealso [ypr_population()]
 #' @export
 #' @examples
 #' ypr_exploitation(ypr_population(pi = 0.4))
 #' ypr_exploitation(ypr_population(pi = 0.4, rho = 0.6, Hm = 0.2))
 ypr_exploitation <- function(population, pi = population$pi) {
-  check_population(population)
-  check_vector(pi, c(0, 1))
-
+  chk_population(population)
+  chk_numeric(pi)
+  chk_not_any_na(pi)
+  chk_range(pi)
   population$pi <- pi
 
   u <- with(population, {
