@@ -1,8 +1,8 @@
 context("sr")
 
 test_that("sr", {
-  bh <- ypr_sr(ypr_population())
-  ri <- ypr_sr(ypr_population(BH = 0L))
+  bh <- ypr_sr(ypr_population(n = ypr:::inst2inter(0.2)))
+  ri <- ypr_sr(ypr_population(BH = 0L, n = ypr:::inst2inter(0.2)))
   expect_is(bh, "data.frame")
   expect_identical(names(bh), c("alpha", "beta", "Rk", "phi", "phiF", "R0", "R0F", "S0", "S0F"))
   expect_identical(names(ri), names(bh))
@@ -20,3 +20,17 @@ test_that("sr", {
   expect_equal(ri$beta, 0.0002468074, check.attributes = FALSE)
   expect_equal(ri$R0F, 0.3395686, check.attributes = FALSE, tolerance = 1e-07)
 })
+
+test_that("ypr_sr extinct population", {
+  bh <- ypr_sr(ypr_population(Linf = 100))
+  expect_equal(bh$R0F, 0.1857959, check.attributes = FALSE, tolerance = 1e-06)
+
+  bh <- ypr_sr(ypr_population(Linf = 100, BH = 0L))
+  expect_equal(bh$R0F, 0.4549179, check.attributes = FALSE, tolerance = 1e-06)
+
+  bh <- ypr_sr(ypr_population(Linf = 140))
+  expect_equal(bh$R0F, 0, check.attributes = FALSE, tolerance = 1e-06)
+
+  bh <- ypr_sr(ypr_population(Linf = 140, BH = 0L))
+  expect_equal(bh$R0F, 0, check.attributes = FALSE, tolerance = 1e-06)
+})
